@@ -1,9 +1,10 @@
 from .unitok import UniTok
-from UniTok.vocab.vocab import Vocab, VocabError
-from UniTok.vocab.depot import VocabDepot, VocabDepotError
+from UniTok.vocab.vocab import Vocab
+from UniTok.vocab.depot import VocabDepot
 from .column import Column
 from .analysis import LengthAnalysis, Plot
 from .unidep import UniDep
+from .classify import Classify
 
 __all__ = [
     UniTok,
@@ -13,6 +14,7 @@ __all__ = [
     Column,
     column,
     analysis,
-    Vocab, VocabError,
-    VocabDepot, VocabDepotError,
+    Vocab,
+    VocabDepot,
+    Classify,
 ]
